@@ -72,7 +72,9 @@ from xdis.cross_dis import (
 
 from xdis.load import (
     check_object_path,
+    is_bytecode_extension,
     is_pypy,
+    is_python_source,
     load_file,
     load_module,
     load_module_from_file_object,
